@@ -1,5 +1,5 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8; coding: utf-8 -*- *
- * gtksourcecompletionmodel.c
+ *
  * This file is part of GtkSourceView
  *
  * Copyright (C) 2009 - Jesse van den Kieboom <jessevdk@gnome.org>
@@ -24,9 +24,9 @@
 #endif
 
 #include "gtksourcecompletionmodel.h"
+#include <glib/gi18n-lib.h>
 #include "gtksourcecompletionprovider.h"
 #include "gtksourcecompletionproposal.h"
-#include "gtksourceview-i18n.h"
 
 typedef struct
 {
